@@ -6,6 +6,11 @@
 {-# LANGUAGE QuasiQuotes                #-}
 {-# LANGUAGE TemplateHaskell            #-}
 {-# LANGUAGE TypeFamilies               #-}
+module Main
+  ( main
+  -- avoid warnings
+  , TestId
+  ) where
 
 import Control.Monad.IO.Class  (liftIO)
 import qualified Data.Text as T
@@ -13,9 +18,9 @@ import Data.Time
 import Database.Persist.Sqlite
 import Database.Persist.TH
 import qualified Database.Sqlite as Sqlite
-import Test.Hspec
 import System.IO (hClose)
 import System.IO.Temp (withSystemTempFile)
+import Test.Hspec
 
 share [mkPersist sqlSettings, mkMigrate "migrateAll"] [persistLowerCase|
 Test
@@ -27,12 +32,12 @@ asIO = id
 
 main :: IO ()
 main = hspec $ do
-    it "issue #328" $ asIO $ runSqlite ":memory:" $ do
+    it "issue #328" $ asIO $ runSqliteInfo (mkSqliteConnectionInfo ":memory:") $ do
         runMigration migrateAll
-        insert . Test $ read "2014-11-30 05:15:25.123"
+        _ <- insert . Test $ read "2014-11-30 05:15:25.123"
         [Single x] <- rawSql "select strftime('%s%f',time) from test" []
         liftIO $ x `shouldBe` Just ("141732452525.123" :: String)
-    it "issue #339" $ asIO $ runSqlite ":memory:" $ do
+    it "issue #339" $ asIO $ runSqliteInfo (mkSqliteConnectionInfo ":memory:") $ do
         runMigration migrateAll
         now <- liftIO getCurrentTime
         tid <- insert $ Test now
@@ -43,3 +48,6 @@ main = hspec $ do
         conn <- Sqlite.open (T.pack fp)
         Sqlite.close conn
         return ()
+    it "issue #527" $ asIO $ runSqliteInfo (mkSqliteConnectionInfo ":memory:") $ do
+        runMigration migrateAll
+        insertMany_ $ replicate 1000 (Test $ read "2014-11-30 05:15:25.123")
